/*++

Copyright (c) 2010-2020 ELMOS Co., Ltd.

Module Name:
	MAI2088.h
Abstract:
	MAI-2088 API library definitions
Revision History:
	10/01/19	Created.
	10/04/09	Added explicit link support.
	10/05/20	Modified response time.
	11/12/21	Modified response time.
	13/05/01	Support for Windows 8.
	15/02/09	Modified response time.
	20/01/17	Modified handle processing.

--*/

#ifndef MAI2088_H
#define MAI2088_H

#ifdef MAI2088_EXPORTS_
#define MAI2088_API __declspec(dllexport)
#else
#define MAI2088_API __declspec(dllimport)
#endif


//
// Device handle
//
typedef void *MAI2088_HANDLE;

//
// Device status (Return value)
//
enum {
    MAI2088_OK,
    MAI2088_INVALID_HANDLE,
    MAI2088_DEVICE_NOT_FOUND,
    MAI2088_DEVICE_NOT_OPENED,
	MAI2088_OTHER_ERROR,
	MAI2088_COMMUNICATION_ERROR,
    MAI2088_OUT_OF_RANGE_PARAMETER
};

//
// Constants
//
#define MAI2088_LOW		0
#define MAI2088_HIGH	1
#define MAI2088_OFF		0
#define MAI2088_ON		1

#define	MAI2088_ENCODER_SENSITIVITY_LEVEL1	0
#define	MAI2088_ENCODER_SENSITIVITY_LEVEL2	1
#define	MAI2088_ENCODER_SENSITIVITY_LEVEL3	2
#define	MAI2088_ENCODER_SENSITIVITY_LEVEL4	3
#define	MAI2088_ENCODER_SENSITIVITY_LEVEL5	4
#define	MAI2088_ENCODER_SENSITIVITY_LEVEL6	5
#define	MAI2088_ENCODER_SENSITIVITY_LEVEL7	6
#define	MAI2088_ENCODER_SENSITIVITY_LEVEL8	7

#ifdef __cplusplus
extern "C" {
#endif

//
// Function definitions
//
MAI2088_API int WINAPI MAI2088_getNumberOfDevices (int *number);
MAI2088_API int WINAPI MAI2088_getSerialNumber (int index, int *serialNumber);
MAI2088_API int WINAPI MAI2088_open (MAI2088_HANDLE *handle);
MAI2088_API int WINAPI MAI2088_openBySerialNumber (int serialNumber, MAI2088_HANDLE *handle);
MAI2088_API int WINAPI MAI2088_close (MAI2088_HANDLE handle);

MAI2088_API int WINAPI MAI2088_initialize (MAI2088_HANDLE handle);
MAI2088_API int WINAPI MAI2088_getVersion (MAI2088_HANDLE handle, int *version);

MAI2088_API int WINAPI MAI2088_getAnalogInputValue (MAI2088_HANDLE handle, int index, int *value);
MAI2088_API int WINAPI MAI2088_getDigitalInputState (MAI2088_HANDLE handle, int index, int *state);
MAI2088_API int WINAPI MAI2088_getDigitalOutputState (MAI2088_HANDLE handle, int index, int *state);
MAI2088_API int WINAPI MAI2088_setDigitalOutputState (MAI2088_HANDLE handle, int index, int state);

MAI2088_API int WINAPI MAI2088_getPotentiometerValue (MAI2088_HANDLE handle, int index, int *value);
MAI2088_API int WINAPI MAI2088_setEncoderSensitivity (MAI2088_HANDLE handle, int index, int level);
MAI2088_API int WINAPI MAI2088_getEncoderPulse (MAI2088_HANDLE handle, int index, int *pulseCount);
MAI2088_API int WINAPI MAI2088_getSwitchState (MAI2088_HANDLE handle, int index, int *state);
MAI2088_API int WINAPI MAI2088_setLEDState (MAI2088_HANDLE handle, int index, int state);
MAI2088_API int WINAPI MAI2088_setLEDBrightness (MAI2088_HANDLE handle, int index, int brightness);
MAI2088_API int WINAPI MAI2088_setLEDBlink (MAI2088_HANDLE handle, int index, double frequency, int dutyCycle, int blinkCount);
MAI2088_API int WINAPI MAI2088_set7SegmentLED (MAI2088_HANDLE handle, int activeType, char displayCharactor, int dotPoint);

#ifdef __cplusplus
}
#endif

#endif  /* MAI2088_H */